@@ -11,9 +11,12 @@ from hai import HaiFile
 from .components.haiddf.hepai_client import HepAIClient as HepAI
 from .components.haiddf.hepai_client import AsyncHepAIClient as AsyncHepAI
 
-
 from .types import Stream, ChatCompletion, ChatCompletionChunk
 
 # from .components.haiddf.hepai_client import AsycnHepAIClient as AsyncHepAI
-from .types import HRModel, LRModel, HModelConfig, HWorkerConfig, HWorkerAPP
+from .types import HRModel, LRModel, HModelConfig, HWorkerConfig, HWorkerAPP, RemoteModel
+from .components.utils import connect
+
+# from .agents import *
+
 
