@@ -28,6 +28,6 @@ from ..components.haiddf.hclient._hclient import (
     )
 
 from ..components.haiddf.worker.worker_app import HWorkerAPP, HWorkerConfig
-from ..components.haiddf.hclient._remote_model import LRModel
+from ..components.haiddf.hclient._remote_model import LRModel, RemoteModel
 
 
